@@ -1,5 +1,5 @@
-import { fake } from '@tamanu/shared/test-helpers';
-import { LAB_REQUEST_STATUSES, LAB_TEST_STATUSES } from '@tamanu/constants';
+import { fake } from '@tamanu/fake-data/fake';
+import { LAB_REQUEST_STATUSES } from '@tamanu/constants';
 import { chance } from '../../../chance';
 
 export const insertCovidTest = async ({ LabTest, LabRequest }, setupData, { encounterId }) => {
@@ -7,7 +7,7 @@ export const insertCovidTest = async ({ LabTest, LabRequest }, setupData, { enco
     ...fake(LabRequest),
     labTestCategoryId: chance.pickone(setupData.labTestCategories).id,
     status: chance.pickone(
-      Object.values(LAB_REQUEST_STATUSES).filter(s => s !== LAB_REQUEST_STATUSES.DELETED),
+      Object.values(LAB_REQUEST_STATUSES).filter((s) => s !== LAB_REQUEST_STATUSES.DELETED),
     ),
     encounterId,
   });
@@ -15,6 +15,5 @@ export const insertCovidTest = async ({ LabTest, LabRequest }, setupData, { enco
     ...fake(LabTest),
     labRequestId: labRequest.id,
     date: chance.date({ year: chance.integer({ min: 1970, max: 2021 }) }),
-    status: LAB_TEST_STATUSES.RECEPTION_PENDING, // LabTest.status isn't set in prod
   });
 };
