@@ -1,7 +1,7 @@
 import { DataTypes } from 'sequelize';
 import { SYNC_DIRECTIONS } from '@tamanu/constants';
 import { Model } from './Model';
-import type { InitOptions } from '../types/model';
+import type { InitOptions, Models } from '../types/model';
 import type { ModelSanitizeArgs } from '../types/sync';
 
 export class Asset extends Model {
@@ -9,6 +9,7 @@ export class Asset extends Model {
   declare name?: string;
   declare type?: string;
   declare data?: Buffer;
+  declare facilityId?: string;
 
   static initModel({ primaryKey, ...options }: InitOptions) {
     super.init(
@@ -25,6 +26,13 @@ export class Asset extends Model {
     );
   }
 
+  static initRelations(models: Models) {
+    this.belongsTo(models.Facility, {
+      foreignKey: 'facilityId',
+      as: 'facility',
+    });
+  }
+
   /**
    * This is only used when inserting asset manually through RestClient
    * Asset is PULL_FROM_CENTRAL, i.e. we don't sync asset up from devices to sync servers.
